@@ -270,6 +270,8 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     "AUTHORS"             => '\u{edca}',            // 
     "AUTHORS.txt"         => '\u{edca}',            // 
     "bashrc"              => Icons::SHELL,          // 󱆃
+    "brewfile"            => '\u{f1116}',           // 󱄖
+    "brewfile.lock.json"  => '\u{f1116}',           // 󱄖
     "bspwmrc"             => '\u{f355}',            // 
     "build.gradle.kts"    => Icons::GRADLE,         // 
     "build.zig.zon"       => '\u{e6a9}',            // 
